# Overview The how-to guides offer a more comprehensive overview of all the tools 🤗 Datasets offers and how to use them. This will help you tackle messier real-world datasets where you may need to manipulate the dataset structure or content to get it ready for training. The guides assume you are familiar and comfortable with the 🤗 Datasets basics. We recommend newer users check out our [tutorials](tutorial) first. Interested in learning more? Take a look at [Chapter 5](https://huggingface.co/course/chapter5/1?fw=pt) of the Hugging Face course! The guides are organized into six sections: - General usage: Functions for general dataset loading and processing. The functions shown in this section are applicable across all dataset modalities. - Audio: How to load, process, and share audio datasets. - Vision: How to load, process, and share image datasets. - Text: How to load, process, and share text datasets. - Tabular: How to load, process, and share tabular datasets. - Dataset repository: How to share and upload a dataset to the Hub. If you have any questions about 🤗 Datasets, feel free to join and ask the community on our [forum](https://discuss.huggingface.co/c/datasets/10).